==> babel-plugin-jsdoc-to-assert-1.3.0.tgz: package/src/index.js <==
// LICENSE : MIT
"use strict";
class SimpleGenerator {
  assert(expression) {
    return `console.assert(${expression});`;
  }
}
function maybeSkip(path) {
  const {node} = path;
  if (node.leadingComments != null && node.leadingComments.length > 0) {
    return false;
  }
  return true;
}
import {CommentConverter} from "jsdoc-to-assert"

export default function ({types: t, template}) {
  const injectAssert = (path, leadingComments, options) => {
    const isSimple = options.simple || false;
    const converterOptions = isSimple ? {
      Generator: SimpleGenerator
    } : {};
    const comment = leadingComments[0];
    if (comment.type === 'CommentBlock') {
      const functionDeclarationString = CommentConverter.toAsserts(comment, converterOptions).join("\n");
      const buildAssert = template(functionDeclarationString)();
      path.get("body").unshiftContainer("body", buildAssert);
    }
  };
  return {
    visitor: {
      // TODO: way?
      // ArrowFunctionExpression | VariableDeclaration
      // VariableDeclaration(path){
      //   if (maybeSkip(path)) {
      //     return;
      //   }
      //   const {node} = path;
      //   if (node.declarations) {
      //     node.declarations.forEach(declaration => {
      //       const declarator = t.variableDeclarator(declaration.id, declaration.init);
      //       console.log(declarator.unshiftContainer);
      //       injectAssert(declarator, node.leadingComments);
      //     });
      //   }
      // },
      ExportNamedDeclaration(path){
        if (maybeSkip(path)) {
          return;
        }
        const {node} = path;
        if (node.declaration) {
          let declaration = path.get("declaration");
          if (declaration.isVariableDeclaration()) {
            return;
          }
          injectAssert(declaration, node.leadingComments, this.opts)
        }
      },
      // method
      ["ObjectMethod|ClassMethod|FunctionDeclaration"](path){
        if (maybeSkip(path)) {
          return;
        }
        const {node} = path;
        injectAssert(path, node.leadingComments, this.opts);
      }
    }
  };
}

==> babel-plugin-jsdoc-to-assert-1.3.1.tgz: package/src/index.js <==
// LICENSE : MIT
"use strict";
class SimpleGenerator {
  assert(expression) {
    return `console.assert(${expression});`;
  }
}
function maybeSkip(path) {
  const {node} = path;
  if (node.leadingComments != null && node.leadingComments.length > 0) {
    return false;
  }
  return true;
}
import {CommentConverter} from "jsdoc-to-assert"

export default function ({types: t, template}) {
  const injectAssert = (path, leadingComments, options) => {
    const isSimple = options.simple || false;
    const converterOptions = isSimple ? {
      Generator: SimpleGenerator
    } : {};
    const comment = leadingComments[leadingComments.length - 1];
    if (comment.type === 'CommentBlock') {
      const functionDeclarationString = CommentConverter.toAsserts(comment, converterOptions).map(line => line.trim()).join("\n");
      const buildAssert = template(functionDeclarationString)();
      path.get("body").unshiftContainer("body", buildAssert);
    }
  };
  return {
    visitor: {
      // TODO: way?
      // ArrowFunctionExpression | VariableDeclaration
      // VariableDeclaration(path){
      //   if (maybeSkip(path)) {
      //     return;
      //   }
      //   const {node} = path;
      //   if (node.declarations) {
      //     node.declarations.forEach(declaration => {
      //       const declarator = t.variableDeclarator(declaration.id, declaration.init);
      //       console.log(declarator.unshiftContainer);
      //       injectAssert(declarator, node.leadingComments);
      //     });
      //   }
      // },
      ExportNamedDeclaration(path){
        if (maybeSkip(path)) {
          return;
        }
        const {node} = path;
        if (node.declaration) {
          let declaration = path.get("declaration");
          if (declaration.isVariableDeclaration()) {
            return;
          }
          injectAssert(declaration, node.leadingComments, this.opts)
        }
      },
      // method
      ["ObjectMethod|ClassMethod|FunctionDeclaration"](path){
        if (maybeSkip(path)) {
          return;
        }
        const {node} = path;
        injectAssert(path, node.leadingComments, this.opts);
      }
    }
  };
}
